Package: scmeth
Type: Package
Title: Functions to conduct quality control analysis in methylation
        data
Version: 1.33.0
Author: Divy Kangeyan <divyswar01@g.harvard.edu>
Maintainer: Divy Kangeyan <divyswar01@g.harvard.edu>
Depends: R (>= 3.5.0)
Imports: BiocGenerics, bsseq, AnnotationHub, Seqinfo, GenomicRanges,
        reshape2, stats, utils, BSgenome, DelayedArray (>= 0.5.15),
        annotatr, SummarizedExperiment (>= 1.5.6), GenomeInfoDb,
        Biostrings, DT, HDF5Array (>= 1.7.5)
Suggests: knitr, rmarkdown, BSgenome.Mmusculus.UCSC.mm10,
        BSgenome.Hsapiens.NCBI.GRCh38,
        TxDb.Hsapiens.UCSC.hg38.knownGene, org.Hs.eg.db, Biobase,
        ggplot2, ggthemes
Description: Functions to analyze methylation data can be found here.
        Some functions are relevant for single cell methylation data
        but most other functions can be used for any methylation data.
        Highlight of this workflow is the comprehensive quality control
        report.
biocViews: DNAMethylation, QualityControl, Preprocessing, SingleCell,
        ImmunoOncology
BugReports: https://github.com/aryeelab/scmeth/issues
License: GPL-2
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Config/pak/sysreqs: cmake make libbz2-dev libicu-dev liblzma-dev
        libpng-dev libuv1-dev libxml2-dev libssl-dev libx11-dev
        xz-utils zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 12:47:18 UTC
RemoteUrl: https://github.com/bioc/scmeth
RemoteRef: HEAD
RemoteSha: f2ec0ad6754a7ae0f7db4480cf06eacb2a3052b9
NeedsCompilation: no
Packaged: 2026-05-30 09:44:15 UTC; root
Built: R 4.6.0; ; 2026-05-30 14:21:36 UTC; unix
