# Generated by roxygen2: do not edit by hand

export(bsConversionPlot)
export(chromosomeCoverage)
export(coverage)
export(cpgDensity)
export(cpgDiscretization)
export(downsample)
export(featureCoverage)
export(mbiasplot)
export(methylationDist)
export(readmetrics)
export(repMask)
export(report)
import(BSgenome)
import(DT)
import(GenomicRanges)
import(SummarizedExperiment)
importFrom(BiocGenerics,organism)
importFrom(Biostrings,DNAString)
importFrom(Biostrings,vmatchPattern)
importFrom(DelayedArray,colMeans)
importFrom(DelayedArray,colSums)
importFrom(DelayedArray,rowSums)
importFrom(GenomeInfoDb,seqlevelsStyle)
importFrom(HDF5Array,loadHDF5SummarizedExperiment)
importFrom(Seqinfo,seqnames)
importFrom(annotatr,annotate_regions)
importFrom(annotatr,build_annotations)
importFrom(annotatr,builtin_genomes)
importFrom(annotatr,summarize_annotations)
importFrom(bsseq,getCoverage)
importFrom(stats,aggregate)
importFrom(stats,dbinom)
importFrom(stats,sd)
importFrom(utils,read.csv)
importFrom(utils,read.table)
