[![Build Status](https://travis-ci.org/aryeelab/scmeth.svg?branch=master)](https://travis-ci.org/aryeelab/scmeth)

# scmeth
**scmeth** is a quality Control analysis package for methylation data. See the package vignette for various functions in the package. 
